<?php

/**
 * Twitter class, extending from SimplePie class which is available at <code>wp-includes</code> folder.
 *
 * @author James Lloyd R. Atwil
 * @version 1.3
 */
class Padd_Twitter extends SimplePie {

	/**
	 * The Twitter username.
	 *
	 * @var string
	 */
	protected $username;

	/**
	 * Number of tweets to be displayed at a time.
	 *
	 * @var int
	 */
	protected $limit;

	/**
	 * Sets the tweets are in unordered list mode or not.
	 *
	 * @var boolean
	 */
	protected $list_mode;

	protected $followers_count = null;

	protected $friends_count = null;

	protected $listed_count = null;

	protected $statuses_count = null;

	protected $profile_image_url = null;

	/**
	 * Constructor for Twitter class.
	 *
	 * @param string $username
	 * @param int $limit
	 * @param boolean $list_mode
	 */
	public function __construct($username, $limit = 1, $list_mode = false) {
		$this->username = $username;
		$this->limit = $limit;
		$this->list_mode = $list_mode;
		if (method_exists(parent,'__construct')) {
			parent::__construct();
		} else {
			$this->SimplePie();
		}
		if (!empty($this->username)) {
			$this->set_feed_url('http://twitter.com/statuses/user_timeline/' . $username . '.rss');
			$this->set_cache_class('WP_Feed_Cache');
			$this->init();

			$data = Padd_Theme_Option::get('data_twitter_users','');
			$data = unserialize($data);
			$next = Padd_Theme_Option::get('data_twitter_users_next','0000-00-00 00:00:00');
			$curr = date('Y-m-d H:i:s');

			if (empty($data)) {
				$data = $this->fetch_user_data();
				if ($data) {
					$sdat = serialize($data);
					Padd_Theme_Option::set('data_twitter_users', $sdat);
					$next = date('Y-m-d H:i:s', time() + 3600);
					Padd_Theme_Option::set('data_twitter_users_next', $next);
				}
			} else {
				if ($curr > $next) {
					$data = $this->fetch_user_data();
					if ($data) {
						$sdat = serialize($data);
						Padd_Theme_Option::set('data_twitter_users', $sdat);
						$next = date('Y-m-d H:i:s', time() + 3600);
						Padd_Theme_Option::set('data_twitter_users_next', $next);
					}
				}
			}

			Padd_Theme_Option::update();

			try {
				$xml = new SimpleXMLElement($data);
				$this->followers_count = intval($xml->followers_count);
				$this->friends_count = intval($xml->friends_count);
				$this->listed_count = intval($xml->listed_count);
				$this->statuses_count = intval($xml->statuses_count);
				$this->profile_image_url = $xml->profile_image_url;
			} catch (Exception $e) {

			}
		}
	}

	/**
	 * Returns the Twitter username.
	 *
	 * @return string
	 */
	public function get_username() {
		return $this->username;
	}

	/**
	 * Sets the Twitter username.
	 *
	 * @param string $username
	 */
	public function set_username($username) {
		$this->username = $username;
	}

	/**
	 * Returns the number of tweets at a time.
	 *
	 * @return int
	 */
	public function get_limit() {
		return $this->limit;
	}

	/**
	 * Sets the number of tweets at a time.
	 *
	 * @param int $limit
	 */
	public function set_limit($limit) {
		$this->limit = $limit;
	}

	/**
	 * Returns whether the tweets are in list mode or not.
	 *
	 * @return <
	 */
	public function get_list_mode() {
		return $this->list_mode;
	}

	public function set_list_mode($list_mode) {
		$this->list_mode = $list_mode;
	}

	/**
	 * Function to render the tweets.
	 */
	public function show_tweets() {

		if ($this->list_mode) {
			echo '<ul class="padd-twitter">';
		}

		if (empty($this->username)) {
			if ($this->list_mode) {
				echo '<li>';
			} else {
				echo '<p class="padd-twitter-message">';
			}
			echo __('Twitter settings is not configured.', PADD_THEME_SLUG);
			if ($this->list_mode) {
				echo '</li>';
			} else {
				echo '</p>';
			}
		} else {
			$count = $this->get_item_quantity();
			if ($count > 0) {
				$i = 0;
				foreach ($this->get_items(0, $this->limit) as $item) {
					$message = $item->get_description();
					$message = substr(strstr($message,': '), 2, strlen($message));
					if ($this->list_mode) {
						echo '<li class="padd-twitter-item">';
					} else if ($num != 1) {
						echo '<p class="padd-twitter-message">';
					}

			          $message = $this->parse_hyperlinks($message);
			          $message = Padd_Twitter::parse_twitter_users($message);

			          echo $message;
					$time = strtotime($item->get_date());

					if ((abs(time()-$time)) < 86400 ) {
						$h_time = sprintf(__('%s ago'), human_time_diff($time));
					} else {
						$h_time = date(__('g:i A F jS'), $time);
					}

			          echo ' <br><span class="padd-twitter-timestamp"><abbr title="' . date(__('Y/m/d H:i:s'), $time) . '">' . $h_time . '</abbr></span>';

					if ($this->list_mode) {
						echo '</li>';
					} elseif ($this->limit != 1) {
						echo '</p>';
					}
					$i++;
					if ( $i >= $this->limit ) {
						break;
					}
				}
			}
			if ($this->list_mode) {
				echo '</ul>';
			}
		}
	}

	/**
	 * Returns the number of followers.
	 *
	 * @return int
	 */
	public function get_followers_count() {
		return $this->followers_count;
	}

	/**
	 * Returns the number of followers in words.
	 *
	 * @param string $zero
	 * @param string $one
	 * @param string $more
	 * @return string
	 */
	public function get_followers_count_words($zero, $one, $more) {
		if ($this->followers_count > 1) {
			return sprintf($more, $this->followers_count);
		} else if ($this->followers_count == 1) {
			return $one;
		} else if ($this->followers_count < 1) {
			return $zero;
		}
	}

	/**
	 * Returns the number of friends.
	 *
	 * @return int
	 */
	public function get_friends_count() {
		return $this->friends_count;
	}

	/**
	 * Returns the number of friends in words.
	 *
	 * @param string $zero
	 * @param string $one
	 * @param string $more
	 * @return string
	 */
	public function get_friends_count_words($zero, $one, $more) {
		if ($this->friends_count > 1) {
			return sprintf($more, $this->friends_count);
		} else if ($this->friends_count == 1) {
			return $one;
		} else if ($this->friends_count < 1) {
			return $zero;
		}
	}

	/**
	 * Returns the number of tweets since registration.
	 *
	 * @return int
	 */
	public function get_statuses_count() {
		return $this->statuses_count;
	}

	/**
	 * Returns the number of tweets since registration in words.
	 *
	 * @param string $zero
	 * @param string $one
	 * @param string $more
	 * @return string
	 */
	public function get_statuses_count_words($zero, $one, $more) {
		if ($this->statuses_count > 1) {
			return sprintf($more, $this->statuses_count);
		} else if ($this->statuses_count == 1) {
			return $one;
		} else if ($this->statuses_count < 1) {
			return $zero;
		}
	}

	/**
	 * Returns the number of being listed since registration.
	 *
	 * @return int
	 */
	public function get_listed_count() {
		return $this->listed_count;
	}

	/**
	 * Returns the URL of the profile image.
	 *
	 * @return string
	 */
	public function get_profile_image_url() {
		return $this->profile_image_url;
	}

	/**
	 * Get user data.
	 *
	 * @return string
	 */
	private function fetch_user_data() {
		$url = 'http://twitter.com/users/show.xml?screen_name=' . $this->username;
		$http = new WP_Http();
		$data = $http->get($url);
		if ($data instanceof WP_Error) {
			return false;
		} else {
			return $data['body'];
		}
	}

	/**
	 * Function to parse the hyperlinks (anchors).
	 *
	 * @param string $text
	 * @return string
	 */
	private function parse_hyperlinks($text) {
		// Props to Allen Shaw & webmancers.com
		// match protocol://address/path/file.extension?some=variable&another=asf%
		//$text = preg_replace("/\b([a-zA-Z]+:\/\/[a-z][a-z0-9\_\.\-]*[a-z]{2,6}[a-zA-Z0-9\/\*\-\?\&\%]*)\b/i","<a href=\"$1\" class=\"twitter-link\">$1</a>", $text);
		$text = preg_replace('/\b([a-zA-Z]+:\/\/[\w_.\-]+\.[a-zA-Z]{2,6}[\/\w\-~.?=&%#+$*!]*)\b/i',"<a href=\"$1\" class=\"twitter-link\">$1</a>", $text);
		// match www.something.domain/path/file.extension?some=variable&another=asf%
		//$text = preg_replace("/\b(www\.[a-z][a-z0-9\_\.\-]*[a-z]{2,6}[a-zA-Z0-9\/\*\-\?\&\%]*)\b/i","<a href=\"http://$1\" class=\"twitter-link\">$1</a>", $text);
		$text = preg_replace('/\b(?<!:\/\/)(www\.[\w_.\-]+\.[a-zA-Z]{2,6}[\/\w\-~.?=&%#+$*!]*)\b/i',"<a href=\"http://$1\" class=\"twitter-link\">$1</a>", $text);

		// match name@address
		$text = preg_replace("/\b([a-zA-Z][a-zA-Z0-9\_\.\-]*[a-zA-Z]*\@[a-zA-Z][a-zA-Z0-9\_\.\-]*[a-zA-Z]{2,6})\b/i","<a href=\"mailto://$1\" class=\"twitter-link\">$1</a>", $text);
		//mach #trendingtopics. Props to Michael Voigt
		$text = preg_replace('/([\.|\,|\:|\¡|\¿|\>|\{|\(]?)#{1}(\w*)([\.|\,|\:|\!|\?|\>|\}|\)]?)\s/i', "$1<a href=\"http://twitter.com/#search?q=$2\" class=\"twitter-link\">#$2</a>$3 ", $text);
		return $text;
	}

	/**
	 * Function to parse the user tag (the @ sign).
	 *
	 * @param string $text
	 * @return string
	 */
	private function parse_twitter_users($text) {
		$text = preg_replace('/([\.|\,|\:|\¡|\¿|\>|\{|\(]?)@{1}(\w*)([\.|\,|\:|\!|\?|\>|\}|\)]?)\s/i', "$1<a href=\"http://twitter.com/$2\" class=\"twitter-user\">@$2</a>$3 ", $text);
		return $text;
	}


}

