<?php

/**
 * Checks if the value of the Facebook field is URL or username.
 *
 * @param <type> $string
 * @return boolean
 */
function padd_check_facebook_url($string) {
	$url = false;
	if ('http://' == substr($string, 0, 7)) {
		$url = true;
	}
	return $url;
}

/**
 * Trim the title.
 *
 * @param int $length Number of letters.
 * @param string $after Ellipsis by default.
 */
function padd_trim_title($length, $after='...') {
	$title = get_the_title();
	if (strlen($title) > $length ) {
		$title = substr($title, 0, $length);
		echo $title . $after;
	} else {
		echo $title;
	}
}

/**
 * Renders the list of social networking websites.
 */
function padd_theme_widget_socialnet($list=true) {
	global $padd_socialnet;
	$fburl = Padd_Theme_Option::get('sn_username_facebook');
	if (!padd_check_facebook_url($fburl) && !empty($fburl)) {
		$padd_socialnet['facebook']->set_username($fburl);
		$fburl = (string) $padd_socialnet['facebook'];
	}
	$padd_socialnet['feedburner']->set_username(Padd_Theme_Option::get('sn_username_feedburner'));
	$padd_socialnet['flickr']->set_username(Padd_Theme_Option::get('sn_username_flickr'));
	$padd_socialnet['twitter']->set_username(Padd_Theme_Option::get('sn_username_twitter'));
	if ($list) :
?>
<ul class="socialnet">
	<li class="twitter">
		<?php echo sprintf(__('<a href="%s">Twitter</a>', PADD_THEME_SLUG), $padd_socialnet['twitter']); ?>
	</li>
	<li class="facebook">
		<?php echo sprintf(__('<a href="%s">Facebook</a>', PADD_THEME_SLUG), $fburl); ?>
	</li>
	<li class="flickr">
		<?php echo sprintf(__('<a href="%s">Flickr</a>', PADD_THEME_SLUG), $padd_socialnet['flickr']); ?>
	</li>
	<li class="rss">
		<?php echo sprintf(__('<a href="%s">RSS</a>', PADD_THEME_SLUG), $padd_socialnet['feedburner']); ?>
	</li>
</ul>
<?php
	else :
?>
	<?php echo sprintf(__('<a class="icon icon-facebook" href="%s"><span>Facebook</span></a>', PADD_THEME_SLUG), $fburl); ?> <span class="no-display">|</span>
	<?php echo sprintf(__('<a class="icon icon-flickr" href="%s"><span>Flickr</span></a>', PADD_THEME_SLUG), $padd_socialnet['flickr']); ?> <span class="no-display">|</span>
	<?php echo sprintf(__('<a class="icon icon-twitter" href="%s"><span>Twitter</span></a>', PADD_THEME_SLUG), $padd_socialnet['twitter']); ?> <span class="no-display">|</span>
	<?php echo sprintf(__('<a class="icon icon-rss" href="%s"><span>RSS</span></a>', PADD_THEME_SLUG), $padd_socialnet['feedburner']); ?>

<?
	endif;
}

/**
 * Renders the Feedburner subscription form.
 *
 * @param string $description
 */
function padd_theme_widget_feedburner($description = '') {
	global $padd_socialnet;
	$padd_socialnet['feedburner']->set_username(Padd_Theme_Option::get('sn_username_feedburner'));
?>
<p><?php echo $description; ?></p>
<form id="subscribe" action="http://feedburner.google.com/fb/a/mailverify" method="post" target="popupwindow" onsubmit="window.open('http://feedburner.google.com/fb/a/emailverifySubmit?uri=<?php echo urlencode($padd_socialnet['feedburner']); ?>', 'popupwindow', 'scrollbars=yes,width=550,height=520'); return true">
	<span class="input"><input type="text" value="<?php echo __('Enter your email address', PADD_THEME_SLUG); ?>" onfocus="if (this.value == '<?php echo __('Enter your email address', PADD_THEME_SLUG); ?>') {this.value = '';}" onblur="if (this.value == '') { this.value = '<?php echo __('Enter your email address', PADD_THEME_SLUG); ?>'; }" name="email" /></span>
	<button type="submit"><span>Sign Up Now</span></button>
	<input type="hidden" value="<?php echo $padd_socialnet['feedburner']->get_username(); ?>" name="uri"/>
	<input type="hidden" value="News Subscribe" name="title" />
</form>
<?php
}

/**
 * Renders the twitter widget.
 */
function padd_theme_widget_twitter() {
	global $padd_socialnet;
	$padd_socialnet['twitter']->set_username(Padd_Theme_Option::get('sn_username_twitter'));
	$padd_sb_twitter = Padd_Theme_Option::get('sn_username_twitter');
	$twitter = new Padd_Twitter($padd_sb_twitter, 3, true);
	$twitter->show_tweets();
	?>
	<p class="follow"><?php echo sprintf(__('Follow %s', PADD_THEME_SLUG), '<a href="' . $padd_socialnet['twitter'] . '">@' . $padd_sb_twitter . '</a>'); ?></p>
	<?php
}

/**
 * Renders the advertisements.
 */
function padd_theme_widget_sponsors() {
	for ($i=1;$i<=4;$i++) {
		$ad = Padd_Theme_Option::get('ads_125125_' . $i,'');
		echo '<span class="ads ads-',  $i, '">', stripslashes($ad), '</span>';
	}
	echo '<div class="clear"></div>';
}


/**
 * Renders the list of bookmarks.
 */
function padd_theme_widget_bookmarks() {
	$array = array();
	$array[] = 'category_before=';
	$array[] = 'category_after=';
	$array[] = 'categorize=0';
	$array[] = 'title_li=';
	wp_list_bookmarks(implode('&',$array));
}

/**
 * Renders the excerpt of the page.
 */
function padd_theme_page_box_special($pid,$class,$col) {
?>
<div class="box widget box-special box-<?php echo $class; ?>">
	<?php
		wp_reset_query();
		query_posts('page_id=' . $pid);
		add_filter('excerpt_length', 'padd_theme_hook_excerpt_pages_length');
		add_filter('excerpt_more', 'padd_theme_hook_excerpt_pages_more');
		the_post();
		$padd_image_def = get_template_directory_uri() . '/images/thumbnail-page-' . $col . '.png';
	?>
	<h2 class="title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
	<p><?php echo wp_trim_excerpt(''); ?></p>
	<p class="learn-more"><a href="<?php the_permalink(); ?>"><?php echo __('Learn More', PADD_THEME_SLUG); ?></a></p>
	<?php
		remove_filter('excerpt_length', 'padd_theme_hook_excerpt_pages_length');
		remove_filter('excerpt_more', 'padd_theme_hook_excerpt_pages_more');
		wp_reset_query();
	?>
</div>
<?php
}

/**
 * Renders the recent posts, optionally with dates.
 *
 * @global WP_DB $wpdb
 * @global string $wp_locale
 * @param array|string $args
 * @return string
 */
function padd_theme_widget_recent_posts($args = '') {
	global $wpdb, $wp_locale;

	$defaults = array(
		'limit' => '',
		'format' => 'html', 'before' => '',
		'after' => '', 'show_post_count' => false,
		'echo' => 1, 'show_date' => true, 'date_format' => 'F j, Y'
	);

	$r = wp_parse_args($args,$defaults);
	extract($r, EXTR_SKIP);

	if ('' == $type) {
		$type = 'monthly';
	}

	if ('' != $limit) {
		$limit = absint($limit);
		$limit = ' LIMIT ' . $limit;
	}

	$where = apply_filters('getarchives_where',"WHERE post_type = 'post' AND post_status = 'publish'",$r);
	$join = apply_filters('getarchives_join',"", $r);

	$output = '';

	$orderby = "post_date DESC ";
	$query = "SELECT * FROM $wpdb->posts $join $where ORDER BY $orderby $limit";
	$key = md5($query);
	$cache = wp_cache_get('padd_recent_posts','general');
	if (!isset($cache[ $key ])) {
		$arcresults = $wpdb->get_results($query);
		$cache[$key] = $arcresults;
		wp_cache_set('padd_recent_posts',$cache,'general');
	} else {
		$arcresults = $cache[$key];
	}
	if ($arcresults) {
		foreach ((array) $arcresults as $arcresult) {
			if ($arcresult->post_date != '0000-00-00 00:00:00' ) {
				$url = get_permalink($arcresult);
				$arc_title = $arcresult->post_title;
				if ($arc_title) {
					$text = strip_tags(apply_filters('the_title', $arc_title));
				} else {
					$text = $arcresult->ID;
				}
				$img = trim(get_the_post_thumbnail($arcresult->ID, PADD_THEME_SLUG . '-aside'));
				$def = get_template_directory_uri() . '/images/thumbnail-aside.jpg';
				if (empty($img)) {
					$img = '<img src="' . $def . '" alt="Thumbnail" />';
				}
				$output .= '<li>';
				$output .= '<a href="' . get_permalink($arcresult->ID) . '" title="Permalink to ' . $text . '">' . $img . '</a>';
				$output .= '<a href="' . get_permalink($arcresult->ID) . '" title="Permalink to ' . $text . '" class="post-title">' . $text . '</a> ';
				$output .= '<span class="meta">';
				$output .= sprintf(__('Posted on %s', PADD_THEME_SLUG), date(__('F j, Y', PADD_THEME_SLUG), strtotime($arcresult->post_date)));
				$output .= '</li>';
				//$output .= get_archives_link($url, $text, $format, $before, ' - ' . date($date_format,strtotime($arcresult->post_date)) . $after);
			}
		}
	}

	if ($echo) {
		echo $output;
	} else {
		return $output;
	}
}

/**
 * Renders the list of recent comments.
 *
 * @global object $wpdb
 * @global array $comments
 * @global array $comment
 * @param int $limit
 */
function padd_theme_widget_recent_comments($limit=5) {
	global $wpdb, $comments, $comment;

	if ( !$comments = wp_cache_get( 'recent_comments', 'widget' ) ) {
		$comments = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_approved = '1' ORDER BY comment_date_gmt DESC LIMIT $limit");
		wp_cache_add( 'recent_comments', $comments, 'widget' );
	}
	echo '<ul class="comments-recent">';
	if ( $comments ) :
		foreach ( (array) $comments as $comment) :
			echo  '<li class="comments-recent">' . sprintf(__('%1$s on %2$s', PADD_THEME_SLUG), get_comment_author_link(), '<a href="'. get_comment_link($comment->comment_ID) . '">' . get_the_title($comment->comment_post_ID) . '</a>') . '</li>';
		endforeach;
	endif;
	echo '</ul>';
}

/**
 * Renders the tabbed widget.
 */
function padd_theme_widget_tabs() {
	?>
<div id="sidebar-tabs">
	<ul class="header">
		<li class="pop"><a href="#tab-pop"><?php echo __('Blogroll', PADD_THEME_SLUG); ?></a></li>
		<li class="rcp"><a href="#tab-rcp"><?php echo __('Archives', PADD_THEME_SLUG); ?></a></li>
		<li class="rcc"><a href="#tab-rcc"><?php echo __('Categories', PADD_THEME_SLUG); ?></a></li>
	</ul>
	<div id="tab-pop">
		<h4><?php echo __('Blogroll', PADD_THEME_SLUG); ?></h4>
		<ul>
			<?php padd_theme_widget_bookmarks(); ?>
		</ul>
	</div>
	<div id="tab-rcp">
		<h4><?php echo __('Archives', PADD_THEME_SLUG); ?></h4>
		<ul>
			<?php wp_get_archives(); ?>
		</ul>
	</div>
	<div id="tab-rcc">
		<h4><?php echo __('Categories', PADD_THEME_SLUG); ?></h4>
		<ul>
			<?php wp_list_categories('title_li='); ?>
		</ul>
	</div>
</div>
	<?php
}

/**
 * Renders the Facebook Like Box.
 *
 * @paran string $id Facebook numerical ID
 * @param int $w Width of the box
 * @param int $h Height of the box
 * @param int $conn Number of connections
 * @param int $stream News feed streaming. 1 to enable, 0 to disable. The default value is 0.
 * @param int $header Like Box header. 1 to show, 0 to hide. The default value is 0.
 */
function padd_theme_widget_facebook_likebox($w=300,$h=300,$conn=10,$stream=0,$header=0) {
	global $padd_socialnet;
	$fburl = Padd_Theme_Option::get('sn_username_facebook');
	if (!padd_check_facebook_url($fburl)) {
		$padd_socialnet['facebook']->set_username($fburl);
		$fburl = (string) $padd_socialnet['facebook'];
	}
?>
<iframe src="http://www.facebook.com/plugins/likebox.php?href=<?php echo urlencode($fburl); ?>&amp;width=<?php echo $w; ?>&amp;connections=<?php echo $conn; ?>&amp;stream=<?php echo $stream == 1 ? 'true' : 'false'; ?>&amp;header=<?php echo $header == 1 ? 'true' : 'false'; ?>&amp;height=<?php echo $h; ?>" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:<?php echo $w; ?>px; height:<?php echo $h; ?>px;"></iframe>
<?php
}

/**
 * Renders the list of comments.
 *
 * @param string $comment
 * @param string $args
 * @param string $depth
 */
function padd_theme_single_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
		<div class="comment">
			<div class="comment-interior append-clear">
				<div class="comment-author append-clear">
					<div class="comment-avatar"><?php echo get_avatar($comment,'33'); ?></div>
					<div class="comment-meta">
						<span class="author"><?php echo sprintf(__('%s says:', PADD_THEME_SLUG), get_comment_author_link()); ?></span>
						<span class="time"><?php echo get_comment_date(Padd_Theme_Option::get('date_format')); ?></span>
					</div>
				</div>
				<div class="comment-details">
					<div class="comment-details-interior">
						<?php comment_text(); ?>
						<?php if ($comment->comment_approved == '0') : ?>
						<p class="comment-notice"><?php _e('My comment is awaiting moderation.', PADD_THEME_SLUG) ?></p>
						<?php endif; ?>
					</div>
				</div>
				<div class="comment-actions clear">
					<?php edit_comment_link(__('Edit', PADD_THEME_SLUG),'<span class="edit">','</span> | ') ?>
					<?php comment_reply_link(array('respond_id' => 'reply', 'add_below' => 'comment' , 'depth' => $depth, 'max_depth' => $args['max_depth'])) ; ?>
				</div>
			</div>
		</div>
	<?php
}

/**
 * Render the list of trackbacks.
 *
 * @param string $comment
 * @param string $args
 * @param string $depth
 */
function padd_theme_single_trackbacks($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="pings-<?php comment_ID() ?>">
		<?php comment_author_link(); ?>
	<?php
}

/**
 * Renders the featured posts in home page.
 */
function padd_theme_post_featured_posts($exclude=array()) {
	wp_reset_query();
	$featured = Padd_Theme_Option::get('slideshow_cat_id','1');
	$count = Padd_Theme_Option::get('slideshow_cat_limit');
	query_posts('showposts=' . $count . '&cat=' . $featured);
	$padd_image_def = get_template_directory_uri() . '/images/thumbnail-gallery.jpg';
?>
<div id="slideshow">
	<div class="list">
	<?php while (have_posts()) : the_post(); ?>
		<div class="item">
			<a href="<?php the_permalink(); ?>" title="Permanent Link to <?php the_title_attribute(); ?>">
			<?php
				$exclude[] = get_the_ID();
				if (has_post_thumbnail()) {
					the_post_thumbnail(PADD_THEME_SLUG . '-gallery', array('title' => get_the_title()));
				} else {
					echo '<img class="thumbnail" src="' . $padd_image_def . '" />';
				}
			?>
			</a>
		</div>
	<?php endwhile; ?>
	</div>
</div>
<?php
	wp_reset_query();
	return $exclude;
}

function padd_theme_posts_in_featured_work() {
	wp_reset_query();
	$featured = Padd_Theme_Option::get('featured_work_cat_id','1');
	$count = Padd_Theme_Option::get('featured_work_cat_limit');
	query_posts('showposts=' . $count . '&cat=' . $featured);
	$padd_image_def = get_template_directory_uri() . '/images/thumbnail-featured-work.jpg';
	add_filter('excerpt_length', 'padd_theme_hook_excerpt_featured_work_length');
	add_filter('excerpt_more', 'padd_theme_hook_excerpt_featured_work_more');
?>

<div class="list">
<?php while (have_posts()) : the_post(); ?>
	<div class="item">
		<div class="thumbnail">
			<a href="<?php the_permalink(); ?>" title="Permanent Link to <?php the_title_attribute(); ?>">
			<?php
				if (has_post_thumbnail()) {
					the_post_thumbnail(PADD_THEME_SLUG . '-featured-work', array('title' => get_the_title()));
				} else {
					echo '<img alt="Thumbnail" src="' . $padd_image_def . '" />';
				}
			?>
		</a>
		</div>
		<h4><a href="<?php the_permalink(); ?>" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h4>
		<p class="date"><?php the_time(__('F j, Y', PADD_THEME_SLUG)); ?></p>
		<?php the_excerpt(); ?>
	</div>
<?php endwhile; ?>
</div>
<?php
	wp_reset_query();
	remove_filter('excerpt_length','padd_theme_hook_excerpt_featured_work_length');
	remove_filter('excerpt_more', 'padd_theme_hook_excerpt_featured_work_more');
}

function padd_theme_share_button($class='share') {
?>
<ul>
	<li class="facebook"><a name="fb_share" type="button_count" share_url="<?php the_permalink(); ?>"><?php echo __('Share', PADD_THEME_SLUG); ?></a></li>
	<li class="twitter"><a href="http://twitter.com/share?url=<?php echo urlencode(get_permalink());?>&amp;count=horizontal" class="twitter-share-button">Twitter</a></li>
	<li class="google-plus-1"><g:plusone size="medium" count="true"></g:plusone></li>
</ul>
<?php
}
