<?php

if (!function_exists('padd_theme_setup')) {
	function padd_theme_setup() {
		remove_action('wp_head','wp_generator');

		add_theme_support('post-thumbnails');
		add_theme_support('automatic-feed-links');

		// Make theme available for translation
		// Translations can be filed in the /languages/ directory
		load_theme_textdomain(PADD_THEME_SLUG, PADD_THEME_PATH . DIRECTORY_SEPARATOR . 'languages' );

		$locale = get_locale();
		$locale_file = PADD_THEME_PATH . DIRECTORY_SEPARATOR . 'languages' . DIRECTORY_SEPARATOR . $locale . '.php';
		if (is_readable($locale_file)) {
			require_once($locale_file);
		}

		register_nav_menus(array(
			'main' => __('Main Menu', PADD_THEME_SLUG),
		     'footer' => __('Footer Menu', PADD_THEME_SLUG),
		));

		add_image_size(PADD_THEME_SLUG . '-thumbnail',PADD_LOOP_THUMB_W,PADD_LOOP_THUMB_H, true);
		add_image_size(PADD_THEME_SLUG . '-home', PADD_HOME_THUMB_W, PADD_HOME_THUMB_H, true);
		add_image_size(PADD_THEME_SLUG . '-gallery', PADD_GALL_THUMB_W,PADD_GALL_THUMB_H, true);
		add_image_size(PADD_THEME_SLUG . '-featured-work', 66, 56, true);
		add_image_size(PADD_THEME_SLUG . '-related-posts', 136, 70, true);
		add_image_size(PADD_THEME_SLUG . '-aside',45, 45, true);
		add_image_size(PADD_THEME_SLUG . '-category-bar', 230, 230, true);

		wp_enqueue_script('jquery');
		wp_enqueue_script('theme', get_stylesheet_directory_uri() . '/js/frontend.js.php?c=1', array('jquery'), PADD_THEME_VERS, true);
		wp_enqueue_script('share-facebook','http://static.ak.fbcdn.net/connect.php/js/FB.Share', NULL, NULL, true);
		wp_enqueue_script('share-twitter','http://platform.twitter.com/widgets.js', NULL, NULL, true);
		wp_enqueue_script('share-google-plus-1','https://apis.google.com/js/plusone.js', NULL, NULL, true);

		wp_enqueue_style('google-fonts-1', 'http://fonts.googleapis.com/css?family=Crushed');
		wp_enqueue_style('google-fonts-2', 'http://fonts.googleapis.com/css?family=Brawler');
	}
}
add_action('after_setup_theme', 'padd_theme_setup');

function padd_theme_widgets_init() {
	register_sidebar(array(
		'name' => __('Home 1', PADD_THEME_SLUG),
		'description' => __('Home widget at the first column.', PADD_THEME_SLUG),
		'before_widget' => '<div id="%1$s" class="box %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="title">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name' => __('Home 2', PADD_THEME_SLUG),
	     'description' => __('Home widget at the second column.', PADD_THEME_SLUG),
		'before_widget' => '<div id="%1$s" class="box %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="title">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name' => __('Home 3', PADD_THEME_SLUG),
		'description' => __('Home widget at the last column.', PADD_THEME_SLUG),
		'before_widget' => '<div id="%1$s" class="box %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="title">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name' => __('Sidebar - Home Page', PADD_THEME_SLUG),
		'before_widget' => '<div id="%1$s" class="box widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="title">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => __('Sidebar', PADD_THEME_SLUG),
		'before_widget' => '<div id="%1$s" class="box widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="title">',
		'after_title' => '</h3>',
	));
}
add_action('widgets_init', 'padd_theme_widgets_init');

function padd_theme_head_favicon() {
	$icon = Padd_Theme_Option::get('favicon_url','');
	if (!empty($icon)) {
		echo '<link rel="shortcut icon" href="' . $icon . '" />' . "\n";
		echo '<link rel="icon" href="' . $icon . '" />' . "\n";
	}
}
add_action('wp_head', 'padd_theme_head_favicon');

function padd_theme_head_tracker() {
	$tracker = Padd_Theme_Option::get('tracker_head','');
	if (!empty($tracker)) {
		echo stripslashes($tracker);
	}
}
add_action('wp_head', 'padd_theme_head_tracker');

add_filter('excerpt_length', 'padd_theme_hook_excerpt_loop_length');
add_filter('excerpt_more', 'padd_theme_hook_excerpt_loop_more');
add_filter('get_comments_number', 'padd_theme_hook_count_comments',0);
add_filter('wp_page_menu_args', 'padd_theme_hook_menu_args');

function padd_theme_queue_js(){
	if (!is_admin()){
		if ( is_singular() && comments_open() && (get_option('thread_comments') == 1)) {
			wp_enqueue_script('comment-reply');
		}
	}
}
add_action('wp_print_scripts', 'padd_theme_queue_js');